    # -*- coding: utf-8 -*-

import os
import logging
import logging.handlers

from ydl_ai_recommender.src.utils import get_project_path


def create_logger(name, filename=None, is_rotating=False):
    logger = logging.getLogger(name)
    logger.setLevel(logging.DEBUG)

    # 创建handler的输出格式（formatter）
    formatter = logging.Formatter('%(asctime)s - %(levelname)s - %(name)s - %(message)s')

    # 创建一个handler，用于输出控制台，并且设定严重级别
    stream_handler = logging.StreamHandler()
    stream_handler.setLevel(logging.INFO)
    stream_handler.setFormatter(formatter)
    logger.addHandler(stream_handler)

    if filename:
        full_filename = os.path.join(get_project_path(), 'log', filename)
        if is_rotating:
            stream_handler = logging.handlers.TimedRotatingFileHandler(full_filename, when='D', backupCount=14, encoding='utf-8')
        else:
            stream_handler = logging.FileHandler(full_filename, encoding='utf-8')
        stream_handler.setLevel(logging.DEBUG)
        stream_handler.setFormatter(formatter)
        logger.addHandler(stream_handler)

    return logger